from art import text2art
import os
LOG_FILE = "log.txt"

# Get the directory of the current script
script_dir = os.path.dirname(os.path.abspath(__file__))

# Construct the absolute path to banner.txt
banner_file = os.path.join(script_dir, 'banner.txt')

BANNER_FILE = banner_file


def print_colored_text(text, color):
    # ANSI color escape codes
    colors = {
        "red": "\033[91m",
        "green": "\033[92m",
        "yellow": "\033[93m",
        "blue": "\033[94m",
        "purple": "\033[95m",
        "cyan": "\033[96m",
        "white": "\033[97m",
        "reset": "\033[0m",
    }
    color_code = colors.get(color.lower(), "")

    # Print colored text
    print(f"{color_code}{text}{colors['reset']}")


def print_eagle():
    # Print colored ASCII art of an eagle
    eagle = text2art("Eagle")
    print_colored_text(eagle, "blue")

    # Print the content of banner.txt if it exists
    try:
        with open(BANNER_FILE, "r") as banner_file:
            banner_content = banner_file.read()
            print_colored_text(banner_content, "blue")
    except FileNotFoundError:
        print(f"Banner file '{BANNER_FILE}' not found.")



import os
import sys
import json
import argparse
import time
import signal
from tqdm import tqdm
from dotenv import load_dotenv

from .scripts.pl_art import *
# from .scripts.pl_art import print_eagle
from .scripts.document_reader import DocumentAIProcessor
load_dotenv()

# progress_bar = None
LOG_FILE = "log.json"
log_dict = {}
# project_id = os.getenv("PROJECT_ID")
project_id='splendid-howl-419519'
# location = os.getenv("LOCATION")
location = 'us'
# processor_display_name = os.getenv("PROCESSOR_DISPLAY_NAME")
processor_display_name = 'pdf_processor_37877f60-bfc1-4923-8271-96e83dd09627'

document_reader = DocumentAIProcessor(project_id, location, processor_display_name)


import os
import sys
import json
import time
import signal
from tqdm import tqdm
from dotenv import load_dotenv

# from scripts.pl_art import *
# from scripts.pl_art import print_eagle
# from scripts.document_reader import DocumentAIProcessor

load_dotenv()

LOG_FILE = "log.json"
log_dict = {}
project_id = os.getenv("PROJECT_ID")
location = os.getenv("LOCATION")
processor_display_name = os.getenv("PROCESSOR_DISPLAY_NAME")

document_reader = DocumentAIProcessor(project_id, location, processor_display_name)


def handler(signum, frame):
    res = input("\nCtrl-C was pressed. Do you really want to exit? y/n ")
    if res == "y":
        if progress_bar is not None:
            progress_bar.close()
        sys.exit(1)


signal.signal(signal.SIGINT, handler)

load_dotenv()

if not os.path.exists(LOG_FILE):
    with open(LOG_FILE, "w") as log_file:
        json.dump({}, log_file)
else:
    with open(LOG_FILE, "r") as log_file:
        try:
            log_dict = json.load(log_file)
        except json.decoder.JSONDecodeError:
            log_dict = {}


def count_pdf_files(directory):
    return sum(
        [
            len([f for f in files if f.endswith(".pdf")])
            for r, d, files in os.walk(directory)
        ]
    )

def is_log_file_empty():
    with open(LOG_FILE, 'r') as log_file:
        content = log_file.read()
        return content.strip() == '{}'

def traverse_folder(folder_path, continue_scan, doc_obj, progress_bar=None):

    for entry in os.listdir(folder_path):
        path = os.path.join(folder_path, entry)
        if os.path.isdir(path):
            traverse_folder(path, continue_scan, doc_obj, progress_bar=progress_bar)
        elif path.endswith(".pdf"):
            doc_obj.read_document(path)
            doc_obj.cluster_file()
            if continue_scan and log_dict.get(path) is not None:
                continue
            time.sleep(0.5)
            if progress_bar is not None:
                progress_bar.set_postfix(file=path, refresh=True)
                progress_bar.update(1)
            log_dict[path] = True
            with open(LOG_FILE, "w") as log_file:
                json.dump(log_dict, log_file)


def main():

    print_eagle()
    if len(sys.argv) != 2:
        print("Usage: python script.py <folder_path>")
        sys.exit(1)

    folder_path = sys.argv[1]
    if not os.path.isdir(folder_path):
        print("Error: Invalid folder path.")
        sys.exit(1)

    if is_log_file_empty():
        continue_scan = False
    else:
        continue_scan = input("Do you want to continue from where you left off? (yes/no): ")
        continue_scan = continue_scan.lower() == "yes"
        
    if not continue_scan:
        with open(LOG_FILE, "w") as log_file:
            json.dump({}, log_file)
            
    try:
        with open(LOG_FILE, "r") as log_file:
            log_dict = json.load(log_file)
    except FileNotFoundError:
        log_dict = {}

    total_files = count_pdf_files(folder_path)
    processed_files = len(log_dict)
    progress_bar = tqdm(total=total_files, initial=processed_files)
    traverse_folder(folder_path, continue_scan, document_reader, progress_bar=progress_bar)
    with open(LOG_FILE, "w") as log_file:
            json.dump({}, log_file)
    progress_bar.close()



if __name__ == "__main__":
    main()



import os
import re
import shutil
from google.api_core.client_options import ClientOptions
from google.api_core.exceptions import AlreadyExists
from google.cloud import documentai


class DocumentAIProcessor:

    def __init__(self, project_id, location, processor_display_name):
        self.project_id = project_id
        self.location = location
        self.processor_display_name = processor_display_name
        self.document_client = self.create_document_client()
        self.processor = self.create_document_process()

    def create_document_client(self) -> documentai.DocumentProcessorServiceClient:
        # You must set the `api_endpoint` if you use a location other than "us".
        opts = ClientOptions(api_endpoint=f"{self.location}-documentai.googleapis.com")
        return documentai.DocumentProcessorServiceClient(client_options=opts)

    def create_document_process(self) -> documentai.Processor:
        # The full resource name of the location, e.g.:
        # `projects/{project_id}/locations/{location}`
        parent = self.document_client.common_location_path(
            self.project_id, self.location
        )

        # Create a processor with the input config.
        # if a processor with the same name exists, the existing processor will be used.
        try:
            processor = self.document_client.create_processor(
                parent=parent,
                processor=documentai.Processor(
                    type_="OCR_PROCESSOR",
                    display_name=self.processor_display_name,
                ),
            )
        except AlreadyExists:
            processors = self.document_client.list_processors(parent=parent)
            for proc in processors:
                if proc.display_name == self.processor_display_name:
                    processor = proc
                    break
        return processor

    def read_document(self, file_path):
        self.file_path = file_path
        with open(file_path, "rb") as file:
            file_content = file.read()

        raw_document = documentai.RawDocument(
            content=file_content,
            mime_type="application/pdf",
        )

        # Configure the process request
        # `processor.name` is the full resource name of the processor, e.g.:
        # `projects/{project_id}/locations/{location}/processors/{processor_id}`
        request = documentai.ProcessRequest(
            name=self.processor.name, raw_document=raw_document
        )

        result = self.document_client.process_document(request=request)
        self.document = result.document

    def cluster_file(self):
        clustered = False
        pattern = "[-\/\n ]"
        document_pages = self.document.pages
        document_text = self.document.text
        folder_name = os.path.dirname(self.file_path)
        file_name = os.path.basename(self.file_path)
        pl_id = re.sub(pattern, "", re.split("[_ ]", file_name.split(".")[0])[0])

        for page in document_pages:
            for lines in page.lines:
                confidence = round(lines.layout.confidence, 4)
                segment = lines.layout.text_anchor.text_segments[0]
                content = document_text[segment.start_index : segment.end_index].split(
                    " "
                )
                try:
                    content = re.sub(pattern, "", content[1])
                except IndexError:
                    content = content[0]

                if content != pl_id:
                    continue
                if confidence >= 0.9:
                    os.makedirs(os.path.join(folder_name, "accurate"), exist_ok=True)
                    shutil.copy(
                        self.file_path, os.path.join(folder_name, "accurate", file_name)
                    )
                elif 0.8 <= confidence < 0.9:
                    os.makedirs(
                        os.path.join(folder_name, "almost_accurate"), exist_ok=True
                    )
                    shutil.copy(
                        self.file_path,
                        os.path.join(folder_name, "almost_accurate", file_name),
                    )
                elif confidence < 0.8:
                    os.makedirs(os.path.join(folder_name, "ambiguous"), exist_ok=True)
                    shutil.copy(
                        self.file_path,
                        os.path.join(folder_name, "ambiguous", file_name),
                    )
                clustered = True
                break

        if not clustered:
            os.makedirs(os.path.join(folder_name, "unclustered"), exist_ok=True)
            shutil.copy(
                self.file_path, os.path.join(folder_name, "unclustered", file_name)
            )



from setuptools import setup, find_packages
import os
import dotenv
# Get the absolute path to the requirements.txt file
# requirements_file = os.path.join(os.path.dirname(__file__), 'requirements.txt')

# Read the dependencies from requirements.txt
# with open(requirements_file) as f:
#     requirements = f.read().splitlines()

# Get the absolute path to the .env file
env_file = os.path.join(os.path.dirname(__file__), '.env')

# Load the environment variables from the .env file
dotenv.load_dotenv(dotenv_path=env_file)

setup(
    name='accusort',
    version='0.5',
    description="AccuSort is a Python package that sorts image PDF files into segregated folders based on the accuracy of PN numbers detected in the image and the file name.",
    long_description='''
    AccuSort
    ========

    AccuSort is a Python package that sorts image PDF files into segregated folders based on the accuracy of PN numbers detected in the image and the file name.

    Installation
    ------------

    1. Run the `export_variables.sh` script on Mac or Linux, and the corresponding batch file on Windows in the terminal or command prompt.
    2. Install AccuSort using pip:
       ```
       pip install accusort
       ```

    Usage
    -----

    1. In your teminal/command prompt, Navigate to the directory containing the image master folder (the folder containing the image sub-folders).
    2. Run the following command to sort the images:
       ```
       accusort <image_master_folder_name>
       ```
    3. The script saves the segragated folders in the respective subfolders of images.

    ''',
    long_description_content_type='text/markdown',
    author='Sixtysix Technologies',
    author_email='sangeeth@sixtysixtech.com',
        packages=find_packages(include=['eagle', 'eagle.*','eagle.scripts']),
        package_data={
            'eagle': ['scripts/banner.txt'],
        },
    install_requires=[
        'art>=6.1',
        'beautifulsoup4>=4.12.3',
        'cachetools>=5.3.3',
        'certifi>=2024.2.2',
        'charset-normalizer>=3.3.2',
        'colorama>=0.4.6',
        'fire>=0.6.0',
        'google-api-core>=2.18.0',
        'google-auth>=2.29.0',
        'google-cloud-documentai>=2.25.0',
        'googleapis-common-protos>=1.63.0',
        'grpcio>=1.62.1',
        'grpcio-status>=1.62.1',
        'idna>=3.7',
        'pip-chill>=1.0.3',
        'proto-plus>=1.23.0',
        'protobuf>=4.25.3',
        'pyasn1>=0.6.0',
        'pyasn1_modules>=0.4.0',
        'pyfiglet>=1.0.2',
        'python-dotenv>=1.0.1',
        'requests>=2.31.0',
        'rsa>=4.9',
        'six>=1.16.0',
        'soupsieve>=2.5',
        'termcolor>=2.4.0',
        'text2art>=0.2.0',
        'tqdm>=4.66.2',
        'urllib3>=2.2.1'
    ],
    entry_points={
        'console_scripts': [
            'accusort=eagle.main:main',
        ],
    },
)